==> owncloud-4.0.4.tgz: owncloud/apps/calendar/l10n/fa.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "هیچ تقویمی پیدا نشد",
"No events found." => "هیچ رویدادی پیدا نشد",
"Wrong calendar" => "تقویم اشتباه",
"New Timezone:" => "زمان محلی جدید",
"Timezone changed" => "زمان محلی تغییر یافت",
"Invalid request" => "درخواست نامعتبر",
"Calendar" => "تقویم",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "DDD m[ yyyy]{ '&#8212;'[ DDD] m yyyy}",
"Birthday" => "روزتولد",
"Business" => "تجارت",
"Call" => "تماس گرفتن",
"Clients" => "مشتریان",
"Deliverer" => "نجات",
"Holidays" => "روزهای تعطیل",
"Ideas" => "ایده ها",
"Journey" => "سفر",
"Jubilee" => "سالگرد",
"Meeting" => "ملاقات",
"Other" => "دیگر",
"Personal" => "شخصی",
"Projects" => "پروژه ها",
"Questions" => "سوالات",
"Work" => "کار",
"unnamed" => "نام گذاری نشده",
"Does not repeat" => "تکرار نکنید",
"Daily" => "روزانه",
"Weekly" => "هفتهگی",
"Every Weekday" => "هرروز هفته",
"Bi-Weekly" => "دوهفته",
"Monthly" => "ماهانه",
"Yearly" => "سالانه",
"never" => "هرگز",
"by occurrences" => "به وسیله ظهور",
"by date" => "به وسیله تاریخ",
"by monthday" => "به وسیله روزهای ماه",
"by weekday" => "به وسیله روز های هفته",
"Monday" => "دوشنبه",
"Tuesday" => "سه شنبه",
"Wednesday" => "چهارشنبه",
"Thursday" => "پنجشنبه",
"Friday" => "جمعه",
"Saturday" => "شنبه",
"Sunday" => "یکشنبه",
"events week of month" => "رویداد های  هفته هایی از ماه",
"first" => "اولین",
"second" => "دومین",
"third" => "سومین",
"fourth" => "چهارمین",
"fifth" => "پنجمین",
"last" => "آخرین",
"January" => "ژانویه",
"February" => "فبریه",
"March" => "مارس",
"April" => "آوریل",
"May" => "می",
"June" => "ژوءن",
"July" => "جولای",
"August" => "آگوست",
"September" => "سپتامبر",
"October" => "اکتبر",
"November" => "نوامبر",
"December" => "دسامبر",
"by events date" => "به وسیله رویداد های روزانه",
"by yearday(s)" => "به وسیله روز های سال(ها)",
"by weeknumber(s)" => "به وسیله شماره هفته(ها)",
"by day and month" => "به وسیله روز و ماه",
"Date" => "تاریخ",
"Cal." => "تقویم.",
"All day" => "هرروز",
"New Calendar" => "تقویم جدید",
"Missing fields" => "فیلد های گم شده",
"Title" => "عنوان",
"From Date" => "از تاریخ",
"From Time" => "از ساعت",
"To Date" => "به تاریخ",
"To Time" => "به ساعت",
"The event ends before it starts" => "رویداد قبل از شروع شدن تمام شده!",
"There was a database fail" => "یک پایگاه داده فرو مانده است",
"Week" => "هفته",
"Month" => "ماه",
"List" => "فهرست",
"Today" => "امروز",
"Calendars" => "تقویم ها",
"There was a fail, while parsing the file." => "ناتوان در تجزیه پرونده",
"Choose active calendars" => "تقویم فعال را انتخاب کنید",
"Your calendars" => "تقویم های شما",
"CalDav Link" => "CalDav Link",
"Shared calendars" => "تقویمهای به اشترک گذاری شده",
"No shared calendars" => "هیچ تقویمی به  اشتراک گذارده نشده",
"Share Calendar" => "تقویم را به اشتراک بگذارید",
"Download" => "بارگیری",
"Edit" => "ویرایش",
"Delete" => "پاک کردن",
"shared with you by" => "به اشتراک گذارده شده به وسیله",
"New calendar" => "تقویم جدید",
"Edit calendar" => "ویرایش تقویم",
"Displayname" => "نام برای نمایش",
"Active" => "فعال",
"Calendar color" => "رنگ تقویم",
"Save" => "ذخیره سازی",
"Submit" => "ارسال",
"Cancel" => "انصراف",
"Edit an event" => "ویرایش رویداد",
"Export" => "خروجی گرفتن",
"Eventinfo" => "اطلاعات رویداد",
"Repeating" => "در حال تکرار کردن",
"Alarm" => "هشدار",
"Attendees" => "شرکت کنندگان",
"Share" => "به اشتراک گذاردن",
"Title of the Event" => "عنوان رویداد",
"Category" => "نوع",
"Separate categories with commas" => "گروه ها را به وسیله درنگ نما از هم جدا کنید",
"Edit categories" => "ویرایش گروه",
"All Day Event" => "رویداد های روزانه",
"From" => "از",
"To" => "به",
"Advanced options" => "تنظیمات حرفه ای",
"Location" => "منطقه",
"Location of the Event" => "منطقه رویداد",
"Description" => "توضیحات",
"Description of the Event" => "توضیحات درباره رویداد",
"Repeat" => "تکرار",
"Advanced" => "پیشرفته",
"Select weekdays" => "انتخاب روز های هفته ",
"Select days" => "انتخاب روز ها",
"and the events day of year." => "و رویداد های روز از سال",
"and the events day of month." => "و رویداد های روز از ماه",
"Select months" => "انتخاب ماه ها",
"Select weeks" => "انتخاب هفته ها",
"and the events week of year." => "و رویداد هفته ها از سال",
"Interval" => "فاصله",
"End" => "پایان",
"occurrences" => "ظهور",
"Import a calendar file" => "یک پرونده حاوی تقویم وارد کنید",
"Please choose the calendar" => "لطفا تقویم را انتخاب کنید",
"create a new calendar" => "یک تقویم جدید ایجاد کنید",
"Name of new calendar" => "نام تقویم جدید",
"Import" => "ورودی دادن",
"Importing calendar" => "درحال افزودن تقویم",
"Calendar imported successfully" => "افزودن تقویم موفقیت آمیز بود",
"Close Dialog" => "بستن دیالوگ",
"Create a new event" => "یک رویداد ایجاد کنید",
"View an event" => "دیدن یک رویداد",
"No categories selected" => "هیچ گروهی انتخاب نشده",
"Select category" => "انتخاب گروه",
"of" => "از",
"at" => "در",
"Timezone" => "زمان محلی",
"Check always for changes of the timezone" => "همیشه بررسی کنید برای تغییر زمان محلی",
"Timeformat" => "نوع زمان",
"24h" => "24 ساعت",
"12h" => "12 ساعت",
"First day of the week" => "یکمین روز هفته",
"Calendar CalDAV syncing address:" => "Calendar CalDAV syncing address :",
"Users" => "کاربرها",
"select users" => "انتخاب شناسه ها",
"Editable" => "قابل ویرایش",
"Groups" => "گروه ها",
"select groups" => "انتخاب گروه ها",
"make public" => "عمومی سازی"
);

==> owncloud-4.5.7.tgz: owncloud/apps/calendar/l10n/fa.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "هیچ تقویمی پیدا نشد",
"No events found." => "هیچ رویدادی پیدا نشد",
"Wrong calendar" => "تقویم اشتباه",
"New Timezone:" => "زمان محلی جدید",
"Timezone changed" => "زمان محلی تغییر یافت",
"Invalid request" => "درخواست نامعتبر",
"Calendar" => "تقویم",
"Editable" => "قابل ویرایش",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '&#8212;'[ MMM] d yyyy}" => "DDD m[ yyyy]{ '&#8212;'[ DDD] m yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Birthday" => "روزتولد",
"Business" => "تجارت",
"Call" => "تماس گرفتن",
"Clients" => "مشتریان",
"Deliverer" => "نجات",
"Holidays" => "روزهای تعطیل",
"Ideas" => "ایده ها",
"Journey" => "سفر",
"Jubilee" => "سالگرد",
"Meeting" => "ملاقات",
"Other" => "دیگر",
"Personal" => "شخصی",
"Projects" => "پروژه ها",
"Questions" => "سوالات",
"Work" => "کار",
"unnamed" => "نام گذاری نشده",
"New Calendar" => "تقویم جدید",
"Does not repeat" => "تکرار نکنید",
"Daily" => "روزانه",
"Weekly" => "هفتهگی",
"Every Weekday" => "هرروز هفته",
"Bi-Weekly" => "دوهفته",
"Monthly" => "ماهانه",
"Yearly" => "سالانه",
"never" => "هرگز",
"by occurrences" => "به وسیله ظهور",
"by date" => "به وسیله تاریخ",
"by monthday" => "به وسیله روزهای ماه",
"by weekday" => "به وسیله روز های هفته",
"Monday" => "دوشنبه",
"Tuesday" => "سه شنبه",
"Wednesday" => "چهارشنبه",
"Thursday" => "پنجشنبه",
"Friday" => "جمعه",
"Saturday" => "شنبه",
"Sunday" => "یکشنبه",
"events week of month" => "رویداد های  هفته هایی از ماه",
"first" => "اولین",
"second" => "دومین",
"third" => "سومین",
"fourth" => "چهارمین",
"fifth" => "پنجمین",
"last" => "آخرین",
"January" => "ژانویه",
"February" => "فبریه",
"March" => "مارس",
"April" => "آوریل",
"May" => "می",
"June" => "ژوءن",
"July" => "جولای",
"August" => "آگوست",
"September" => "سپتامبر",
"October" => "اکتبر",
"November" => "نوامبر",
"December" => "دسامبر",
"by events date" => "به وسیله رویداد های روزانه",
"by yearday(s)" => "به وسیله روز های سال(ها)",
"by weeknumber(s)" => "به وسیله شماره هفته(ها)",
"by day and month" => "به وسیله روز و ماه",
"Date" => "تاریخ",
"Cal." => "تقویم.",
"All day" => "هرروز",
"Missing fields" => "فیلد های گم شده",
"Title" => "عنوان",
"From Date" => "از تاریخ",
"From Time" => "از ساعت",
"To Date" => "به تاریخ",
"To Time" => "به ساعت",
"The event ends before it starts" => "رویداد قبل از شروع شدن تمام شده!",
"There was a database fail" => "یک پایگاه داده فرو مانده است",
"Week" => "هفته",
"Month" => "ماه",
"List" => "فهرست",
"Today" => "امروز",
"Your calendars" => "تقویم های شما",
"CalDav Link" => "CalDav Link",
"Share Calendar" => "تقویم را به اشتراک بگذارید",
"Download" => "بارگیری",
"Edit" => "ویرایش",
"Delete" => "پاک کردن",
"shared with you by" => "به اشتراک گذارده شده به وسیله",
"New calendar" => "تقویم جدید",
"Edit calendar" => "ویرایش تقویم",
"Displayname" => "نام برای نمایش",
"Active" => "فعال",
"Calendar color" => "رنگ تقویم",
"Save" => "ذخیره سازی",
"Submit" => "ارسال",
"Cancel" => "انصراف",
"Edit an event" => "ویرایش رویداد",
"Export" => "خروجی گرفتن",
"Eventinfo" => "اطلاعات رویداد",
"Repeating" => "در حال تکرار کردن",
"Alarm" => "هشدار",
"Attendees" => "شرکت کنندگان",
"Share" => "به اشتراک گذاردن",
"Title of the Event" => "عنوان رویداد",
"Category" => "نوع",
"Separate categories with commas" => "گروه ها را به وسیله درنگ نما از هم جدا کنید",
"Edit categories" => "ویرایش گروه",
"All Day Event" => "رویداد های روزانه",
"From" => "از",
"To" => "به",
"Advanced options" => "تنظیمات حرفه ای",
"Location" => "منطقه",
"Location of the Event" => "منطقه رویداد",
"Description" => "توضیحات",
"Description of the Event" => "توضیحات درباره رویداد",
"Repeat" => "تکرار",
"Advanced" => "پیشرفته",
"Select weekdays" => "انتخاب روز های هفته ",
"Select days" => "انتخاب روز ها",
"and the events day of year." => "و رویداد های روز از سال",
"and the events day of month." => "و رویداد های روز از ماه",
"Select months" => "انتخاب ماه ها",
"Select weeks" => "انتخاب هفته ها",
"and the events week of year." => "و رویداد هفته ها از سال",
"Interval" => "فاصله",
"End" => "پایان",
"occurrences" => "ظهور",
"create a new calendar" => "یک تقویم جدید ایجاد کنید",
"Import a calendar file" => "یک پرونده حاوی تقویم وارد کنید",
"Name of new calendar" => "نام تقویم جدید",
"Import" => "ورودی دادن",
"Close Dialog" => "بستن دیالوگ",
"Create a new event" => "یک رویداد ایجاد کنید",
"View an event" => "دیدن یک رویداد",
"No categories selected" => "هیچ گروهی انتخاب نشده",
"of" => "از",
"at" => "در",
"Timezone" => "زمان محلی",
"24h" => "24 ساعت",
"12h" => "12 ساعت"
);
